var searchData=
[
  ['libinput_5fconfig_5fstatus_5fto_5fstr',['libinput_config_status_to_str',['../group__config.html#ga7eee5ba99988d80bb9dd744894c72e06',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fdefault_5fspeed',['libinput_device_config_accel_get_default_speed',['../group__config.html#ga71fba19df9d2cb15904c6351cec1af35',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fspeed',['libinput_device_config_accel_get_speed',['../group__config.html#gaac7c1b31e0131154d31b9167c876cc3b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fis_5favailable',['libinput_device_config_accel_is_available',['../group__config.html#ga77b20c16fe26f385936f1d8cb4a1a560',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5faccel_5fset_5fspeed',['libinput_device_config_accel_set_speed',['../group__config.html#ga1d9761bb99b445524fb2ea801f946ef1',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fdefault_5fmatrix',['libinput_device_config_calibration_get_default_matrix',['../group__config.html#ga3d9f1b9be10e804e170c4ea455bd1f1b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fmatrix',['libinput_device_config_calibration_get_matrix',['../group__config.html#gaa16e8b272ce94f8037822dc8c89d84a5',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fhas_5fmatrix',['libinput_device_config_calibration_has_matrix',['../group__config.html#gadd921b0caef6fcf05199a93e5ee0728b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fcalibration_5fset_5fmatrix',['libinput_device_config_calibration_set_matrix',['../group__config.html#ga09a798f58cc601edd2797780096e9804',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fget_5fdefault_5fmethod',['libinput_device_config_click_get_default_method',['../group__config.html#ga574f5bce37a87b6e05a956481748e9b4',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fget_5fmethod',['libinput_device_config_click_get_method',['../group__config.html#ga6aa5fc908b050beb6c0346a09478cad4',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fget_5fmethods',['libinput_device_config_click_get_methods',['../group__config.html#ga30f433d7c21fc8e65dd218079ce1a2a9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fclick_5fset_5fmethod',['libinput_device_config_click_set_method',['../group__config.html#gadfd0d6c30f8d87ae570c9159953de3c9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget',['libinput_device_config_left_handed_get',['../group__config.html#ga998945b1c4f96a9abd3c3a26e5c4166c',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fget_5fdefault',['libinput_device_config_left_handed_get_default',['../group__config.html#gaa438a14e32894791e435cb43826ef3a9',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fis_5favailable',['libinput_device_config_left_handed_is_available',['../group__config.html#ga755352f2bbb869446aa591dd9d9c5eaf',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fleft_5fhanded_5fset',['libinput_device_config_left_handed_set',['../group__config.html#ga9bbdef04c07804ce7c121133c04d4edf',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fget_5fdefault_5fenabled',['libinput_device_config_middle_emulation_get_default_enabled',['../group__config.html#ga602bf0edd3553972cd2d1f841401578b',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fget_5fenabled',['libinput_device_config_middle_emulation_get_enabled',['../group__config.html#ga4669a9e2eeda7ddd648d340935c40ada',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fis_5favailable',['libinput_device_config_middle_emulation_is_available',['../group__config.html#gad9d32f1fd776fa112e5eaac6419de6b7',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fmiddle_5femulation_5fset_5fenabled',['libinput_device_config_middle_emulation_set_enabled',['../group__config.html#ga584d862a116fb0a26cc95304f8c13eb1',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fbutton',['libinput_device_config_scroll_get_button',['../group__config.html#ga83623da437d0114b8e3ac29ab771d799',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fbutton',['libinput_device_config_scroll_get_default_button',['../group__config.html#gad4aacefb10fab1e401e211ee9ce0c1e6',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fmethod',['libinput_device_config_scroll_get_default_method',['../group__config.html#ga844ea06b952aaee8e0643d85d351afb6',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fdefault_5fnatural_5fscroll_5fenabled',['libinput_device_config_scroll_get_default_natural_scroll_enabled',['../group__config.html#gaab8cf4106f5836bf92038414b33b3bc3',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fmethod',['libinput_device_config_scroll_get_method',['../group__config.html#ga4bc3cc3822eea632a9a6cf3760ea1fd0',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fmethods',['libinput_device_config_scroll_get_methods',['../group__config.html#gacaad48862a67ca61cb8e257a7e80ee8c',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fget_5fnatural_5fscroll_5fenabled',['libinput_device_config_scroll_get_natural_scroll_enabled',['../group__config.html#gab4074b193c4350597d2221c4c34c0d15',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fhas_5fnatural_5fscroll',['libinput_device_config_scroll_has_natural_scroll',['../group__config.html#ga82d1aa961d2bb2f0c72c22e2441a4fc3',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fset_5fbutton',['libinput_device_config_scroll_set_button',['../group__config.html#gac95a25055b22c3631e3c10c0463ca332',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fset_5fmethod',['libinput_device_config_scroll_set_method',['../group__config.html#ga482951a2b1faf837e43d30d9c92dc9d3',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fscroll_5fset_5fnatural_5fscroll_5fenabled',['libinput_device_config_scroll_set_natural_scroll_enabled',['../group__config.html#ga958b67193c3948b59add719a68f1b948',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fdefault_5fmode',['libinput_device_config_send_events_get_default_mode',['../group__config.html#gaef671857791fcc889f609f6db96f2fe6',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmode',['libinput_device_config_send_events_get_mode',['../group__config.html#gae945f2120764570f0b7c48b69a035543',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fget_5fmodes',['libinput_device_config_send_events_get_modes',['../group__config.html#gaa03e5c609b0b199402048fcd2cf85b24',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5fsend_5fevents_5fset_5fmode',['libinput_device_config_send_events_set_mode',['../group__config.html#gaacc79635146b888ddaf1cb35363b22ce',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_default_drag_lock_enabled',['../group__config.html#gaa9ac23a944aa2232397bcd856cc55055',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdefault_5fenabled',['libinput_device_config_tap_get_default_enabled',['../group__config.html#gaf6906b7344ee8d446594de08b4d065be',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fdrag_5flock_5fenabled',['libinput_device_config_tap_get_drag_lock_enabled',['../group__config.html#ga096a8960db3d6e43c419180270755584',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5fenabled',['libinput_device_config_tap_get_enabled',['../group__config.html#ga8bfe1d541dcadaedeedcd7a98d5b7e07',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fget_5ffinger_5fcount',['libinput_device_config_tap_get_finger_count',['../group__config.html#ga13973d6bd75a99708723e3c6684517c1',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fset_5fdrag_5flock_5fenabled',['libinput_device_config_tap_set_drag_lock_enabled',['../group__config.html#ga8b72d649a4e05a455c1d0ec4194cb755',1,'libinput.h']]],
  ['libinput_5fdevice_5fconfig_5ftap_5fset_5fenabled',['libinput_device_config_tap_set_enabled',['../group__config.html#ga3caf860883d4e2e42b7842599da03e56',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fcontext',['libinput_device_get_context',['../group__device.html#ga90c6868911d8aba103278c9208d5205e',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fdevice_5fgroup',['libinput_device_get_device_group',['../group__device.html#ga0edc58e5a022b48a8d8416f63d2860df',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fid_5fproduct',['libinput_device_get_id_product',['../group__device.html#gae011910b4a673f1293a20a84be4e52e2',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fid_5fvendor',['libinput_device_get_id_vendor',['../group__device.html#gad9e4c074b03da790de5e117c71ce8d50',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fname',['libinput_device_get_name',['../group__device.html#ga31655d2c2f173d059b3f891801c0a429',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5foutput_5fname',['libinput_device_get_output_name',['../group__device.html#gaf48626f6190e9c9bc14abb704e66cc22',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fseat',['libinput_device_get_seat',['../group__device.html#ga27823edb40750992a1a05e7a9f5dc8f0',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fsize',['libinput_device_get_size',['../group__device.html#gab91ae9014902fafe4f015e1f42233d27',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fsysname',['libinput_device_get_sysname',['../group__device.html#ga106bbe58e6c3a6d1327c9bcbbf2a03f6',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fudev_5fdevice',['libinput_device_get_udev_device',['../group__device.html#gaedc690c6679f547c46d9f41182a0e7c9',1,'libinput.h']]],
  ['libinput_5fdevice_5fget_5fuser_5fdata',['libinput_device_get_user_data',['../group__device.html#gaf5c902f56206a5d441e50c3a95ec458b',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup_5fget_5fuser_5fdata',['libinput_device_group_get_user_data',['../group__device.html#ga779d66e502b17a4c4aae6d3c773470f9',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup_5fref',['libinput_device_group_ref',['../group__device.html#ga72f2803f681e074e56e0da63e4ccead2',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup_5fset_5fuser_5fdata',['libinput_device_group_set_user_data',['../group__device.html#gaf252f7535939d813ebe6eb7b2b792446',1,'libinput.h']]],
  ['libinput_5fdevice_5fgroup_5funref',['libinput_device_group_unref',['../group__device.html#ga371124d3d3bec0a7f946acd1c4417efe',1,'libinput.h']]],
  ['libinput_5fdevice_5fhas_5fcapability',['libinput_device_has_capability',['../group__device.html#gaa32d887454e8baf8aaeeb635329aef89',1,'libinput.h']]],
  ['libinput_5fdevice_5fkeyboard_5fhas_5fkey',['libinput_device_keyboard_has_key',['../group__device.html#ga80efc6bbab881c6785f0184ddc97c5ce',1,'libinput.h']]],
  ['libinput_5fdevice_5fled_5fupdate',['libinput_device_led_update',['../group__device.html#gafdb3ddfb91e6bd38b6356a5bb51547ad',1,'libinput.h']]],
  ['libinput_5fdevice_5fpointer_5fhas_5fbutton',['libinput_device_pointer_has_button',['../group__device.html#gaaf63f10e5120daf174bd7943169f45bf',1,'libinput.h']]],
  ['libinput_5fdevice_5fref',['libinput_device_ref',['../group__device.html#ga3335d55a50f0c2fb0c5f496a3105d467',1,'libinput.h']]],
  ['libinput_5fdevice_5fset_5fseat_5flogical_5fname',['libinput_device_set_seat_logical_name',['../group__device.html#ga9f76acc43c8684a13f232073ee829b50',1,'libinput.h']]],
  ['libinput_5fdevice_5fset_5fuser_5fdata',['libinput_device_set_user_data',['../group__device.html#ga6243ad6005b2ce2a5ecfd1b04787fe93',1,'libinput.h']]],
  ['libinput_5fdevice_5funref',['libinput_device_unref',['../group__device.html#ga857340e2dab06c7f7d84173a5a1fa427',1,'libinput.h']]],
  ['libinput_5fdispatch',['libinput_dispatch',['../group__base.html#ga271f910ed17461830e48d4cd20483a00',1,'libinput.h']]],
  ['libinput_5fevent_5fdestroy',['libinput_event_destroy',['../group__event.html#ga1df956c16e26cbbd911e553ec081022a',1,'libinput.h']]],
  ['libinput_5fevent_5fdevice_5fnotify_5fget_5fbase_5fevent',['libinput_event_device_notify_get_base_event',['../group__event.html#ga19d329b7685c3a994718cec3845db1a0',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fcontext',['libinput_event_get_context',['../group__event.html#ga28557ae0295f61c45f9b6e4ff7f86632',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fdevice',['libinput_event_get_device',['../group__event.html#ga8a49a089181960f7536344f7637ea777',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fdevice_5fnotify_5fevent',['libinput_event_get_device_notify_event',['../group__event.html#ga2bbc1391a3397d57d37ae3e2f8175abc',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fkeyboard_5fevent',['libinput_event_get_keyboard_event',['../group__event.html#ga8378f8fdd01e8afbcea8ddbb5411570d',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5fpointer_5fevent',['libinput_event_get_pointer_event',['../group__event.html#ga52acdc3afcf75efeb8153f50eef20615',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5ftouch_5fevent',['libinput_event_get_touch_event',['../group__event.html#gad2cba8252024bdcc341499bedd3d0be7',1,'libinput.h']]],
  ['libinput_5fevent_5fget_5ftype',['libinput_event_get_type',['../group__event.html#ga430a3a7369afd6c5ff722179327df79a',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fbase_5fevent',['libinput_event_keyboard_get_base_event',['../group__event__keyboard.html#gae5a3b7e12e7e8b213b3da92a13adb88d',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fkey',['libinput_event_keyboard_get_key',['../group__event__keyboard.html#gad29cc9f276d9468463d01f65ccf8deaf',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fkey_5fstate',['libinput_event_keyboard_get_key_state',['../group__event__keyboard.html#gaf7b018edbc264ba81a2d475d42ebbd98',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5fseat_5fkey_5fcount',['libinput_event_keyboard_get_seat_key_count',['../group__event__keyboard.html#ga75a647f08ef9df9db7a6ebb9b297add4',1,'libinput.h']]],
  ['libinput_5fevent_5fkeyboard_5fget_5ftime',['libinput_event_keyboard_get_time',['../group__event__keyboard.html#ga0f1a7bb1016816a277b52705d6ef2d71',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fx',['libinput_event_pointer_get_absolute_x',['../group__event__pointer.html#gac221536b90c7beb70b70b52e710291b5',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fx_5ftransformed',['libinput_event_pointer_get_absolute_x_transformed',['../group__event__pointer.html#ga26fa3d0b2bcc7f0a7939b84dc8207021',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy',['libinput_event_pointer_get_absolute_y',['../group__event__pointer.html#ga3e097a9bc6dbbb355fb1982912f72d4c',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fabsolute_5fy_5ftransformed',['libinput_event_pointer_get_absolute_y_transformed',['../group__event__pointer.html#gaa48effb21f132f05f280859f3d2a9f23',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5faxis_5fsource',['libinput_event_pointer_get_axis_source',['../group__event__pointer.html#ga2116f4bbedb61532e71d16c4f87bd4ca',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue',['libinput_event_pointer_get_axis_value',['../group__event__pointer.html#ga81ad7d8a95c456731a874e584c4c8dda',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5faxis_5fvalue_5fdiscrete',['libinput_event_pointer_get_axis_value_discrete',['../libinput_8h.html#a38d12fc6884c9943e261febdb2384b98',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fbase_5fevent',['libinput_event_pointer_get_base_event',['../group__event__pointer.html#ga4d4f75669001c323dcdc3cc9aec1574a',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fbutton',['libinput_event_pointer_get_button',['../group__event__pointer.html#ga6dc942e706a29d342a2021afaa49548b',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fbutton_5fstate',['libinput_event_pointer_get_button_state',['../group__event__pointer.html#ga41e87521ab2a8b7783cb47a63d71da18',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdx',['libinput_event_pointer_get_dx',['../group__event__pointer.html#ga29aaf86185a4c9dfa38d98b1fd4dba53',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdx_5funaccelerated',['libinput_event_pointer_get_dx_unaccelerated',['../group__event__pointer.html#gad517cc1adc1d43b216804af22499587e',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdy',['libinput_event_pointer_get_dy',['../group__event__pointer.html#ga8bb38bb120bbc0ad569c701a6e622612',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fdy_5funaccelerated',['libinput_event_pointer_get_dy_unaccelerated',['../group__event__pointer.html#ga2a9d66358432b4bee5f8c201f8dc8906',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5fseat_5fbutton_5fcount',['libinput_event_pointer_get_seat_button_count',['../group__event__pointer.html#ga1990b268bdc42ff3277bc43dbb3102ea',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fget_5ftime',['libinput_event_pointer_get_time',['../group__event__pointer.html#gac42d0e19d076f4e1fca15f1ec42510d5',1,'libinput.h']]],
  ['libinput_5fevent_5fpointer_5fhas_5faxis',['libinput_event_pointer_has_axis',['../group__event__pointer.html#ga1fdd37a49eae958aaf78a0596cd5cef5',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fbase_5fevent',['libinput_event_touch_get_base_event',['../group__event__touch.html#gacb2cd144a719c9873cd4621db278e92c',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fseat_5fslot',['libinput_event_touch_get_seat_slot',['../group__event__touch.html#gabac75c78a0a360995e1a521edb38c4da',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fslot',['libinput_event_touch_get_slot',['../group__event__touch.html#gaf5294eab86b9125b7fb607049ff9ef09',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5ftime',['libinput_event_touch_get_time',['../group__event__touch.html#ga5d13da5020c6aff78604943690f8cbe9',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fx',['libinput_event_touch_get_x',['../group__event__touch.html#gac42d0e070811c360cf8ec784349954ba',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fx_5ftransformed',['libinput_event_touch_get_x_transformed',['../group__event__touch.html#gadd04ccc3a7b4564e5aca3c8592f090fe',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fy',['libinput_event_touch_get_y',['../group__event__touch.html#ga30711113bcef4bc02eda7878a054351c',1,'libinput.h']]],
  ['libinput_5fevent_5ftouch_5fget_5fy_5ftransformed',['libinput_event_touch_get_y_transformed',['../group__event__touch.html#ga36af95f47b6d69b581eaeee69927af6f',1,'libinput.h']]],
  ['libinput_5fget_5fevent',['libinput_get_event',['../group__base.html#gacead6670eaecf7c807659e2b6c725630',1,'libinput.h']]],
  ['libinput_5fget_5ffd',['libinput_get_fd',['../group__base.html#ga885a59371d4e8de0e18a2a2a66942e11',1,'libinput.h']]],
  ['libinput_5fget_5fuser_5fdata',['libinput_get_user_data',['../group__base.html#ga3eab49413b8430c2eee987a39f4a410b',1,'libinput.h']]],
  ['libinput_5flog_5fget_5fpriority',['libinput_log_get_priority',['../group__base.html#ga7367998ca39a6e873920ba5e2a12d4f0',1,'libinput.h']]],
  ['libinput_5flog_5fset_5fpriority',['libinput_log_set_priority',['../group__base.html#ga75a500c54c61cfcecd4c76dbb8022933',1,'libinput.h']]],
  ['libinput_5fnext_5fevent_5ftype',['libinput_next_event_type',['../group__base.html#gac86ad3c0c5bc27d8f630264f46cdf005',1,'libinput.h']]],
  ['libinput_5fpath_5fadd_5fdevice',['libinput_path_add_device',['../group__base.html#gaa797496f0150b482a4e01376bd33a47b',1,'libinput.h']]],
  ['libinput_5fpath_5fcreate_5fcontext',['libinput_path_create_context',['../group__base.html#ga363c6b6e47dcf410a3b3ebd5547c8b07',1,'libinput.h']]],
  ['libinput_5fpath_5fremove_5fdevice',['libinput_path_remove_device',['../group__base.html#ga9cb53cdcce2c000001ac17706a612121',1,'libinput.h']]],
  ['libinput_5fref',['libinput_ref',['../group__base.html#gafff29392ec52e1e7de5bb812e085127a',1,'libinput.h']]],
  ['libinput_5fresume',['libinput_resume',['../group__base.html#ga5a1ee92fa05df27e3c0f37d524cc17a6',1,'libinput.h']]],
  ['libinput_5fseat_5fget_5fcontext',['libinput_seat_get_context',['../group__seat.html#ga634ac38cf583d1da4e99824860d91efc',1,'libinput.h']]],
  ['libinput_5fseat_5fget_5flogical_5fname',['libinput_seat_get_logical_name',['../group__seat.html#ga61e477120d5f0cc67a06d04575186948',1,'libinput.h']]],
  ['libinput_5fseat_5fget_5fphysical_5fname',['libinput_seat_get_physical_name',['../group__seat.html#gac881036869846ad87eb7814fbf308251',1,'libinput.h']]],
  ['libinput_5fseat_5fget_5fuser_5fdata',['libinput_seat_get_user_data',['../group__seat.html#gac7af04e67fc803f1f7756d02e5372e91',1,'libinput.h']]],
  ['libinput_5fseat_5fref',['libinput_seat_ref',['../group__seat.html#ga60445ab81e8ee3a10b85e88617231069',1,'libinput.h']]],
  ['libinput_5fseat_5fset_5fuser_5fdata',['libinput_seat_set_user_data',['../group__seat.html#ga669ed8a095445e9537deef8a9880587b',1,'libinput.h']]],
  ['libinput_5fseat_5funref',['libinput_seat_unref',['../group__seat.html#ga81d52d0e9332f07c39a899c8c2fd3400',1,'libinput.h']]],
  ['libinput_5fset_5fuser_5fdata',['libinput_set_user_data',['../group__base.html#gac1a020ab0a0da92749e24e80538ab28f',1,'libinput.h']]],
  ['libinput_5fsuspend',['libinput_suspend',['../group__base.html#ga60662dc666f6188dc207467c9d8e99ab',1,'libinput.h']]],
  ['libinput_5fudev_5fassign_5fseat',['libinput_udev_assign_seat',['../group__base.html#ga71a60660b30cb476495e75766222d144',1,'libinput.h']]],
  ['libinput_5fudev_5fcreate_5fcontext',['libinput_udev_create_context',['../group__base.html#ga7512ea602d4b259085c47f6374b078d1',1,'libinput.h']]],
  ['libinput_5funref',['libinput_unref',['../group__base.html#ga7ed0797d23e34b650e0aeb98b5350309',1,'libinput.h']]]
];
